changeset 4045:a37868b332ac

(compilation-error-regexp-alist): Broaden ``Line N of "FILE": msg'' regexp to also match Ultrix f77: ``Error on line N of FILE: msg''.
author Roland McGrath <roland@gnu.org>
date Thu, 08 Jul 1993 23:31:58 +0000
parents ad0643aa3ebf
children 79184227e7f9
files lisp/progmodes/compile.el
diffstat 1 files changed, 6 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/compile.el	Thu Jul 08 22:42:14 1993 +0000
+++ b/lisp/progmodes/compile.el	Thu Jul 08 23:31:58 1993 +0000
@@ -126,8 +126,12 @@
     ;; which is regexp Impressionism - it matches almost anything!
     ("([ \t]*\\([^:( \t\n]+\\)[:(][ \t]*\\([0-9]+\\))" 1 2)
 
-    ;; Line 45 of "foo.c": bloofel undefined (who does this?)
-    ("\n[Ll]ine[ \t]+\\([0-9]+\\)[ \t]+of[ \t]+\"\\([^\"\n]+\\)\":" 2 1)
+    ;; Ultrix 3.0 f77:
+    ;;  Error on line 3 of t.f: Execution error unclassifiable statement    
+    ;; Unknown who does this:
+    ;;  Line 45 of "foo.c": bloofel undefined
+    ("\n\\(Error on \\)?[Ll]ine[ \t]+\\([0-9]+\\)[ \t]+\
+of[ \t]+\"?\\([^\"\n]+\\)\"?:" 3 2)
 
     ;; Apollo cc, 4.3BSD fc:
     ;;	"foo.f", line 3: Error: syntax error near end of statement